@@ -13,4 +13,4 @@ source $thisdir/activate_env.sh "$envdir"
 # modules - see setup.py
 export INDEXED_GZIP_TESTING=1
 
-python setup.py develop
+pip install --no-build-isolation --editable .
